summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix/MatrixHLayout.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:07:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:07:05 -0600
commitc18386d69b76ef0218b5f0a08ca773fa824322b6 (patch)
tree0bea571897791e4a9ae01e42d0923c3c7baf0bda /src/gui/editors/matrix/MatrixHLayout.h
parent97f1c43c867725d49f3943a68ef08d7e71767e99 (diff)
downloadrosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.tar.gz
rosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'src/gui/editors/matrix/MatrixHLayout.h')
-rw-r--r--src/gui/editors/matrix/MatrixHLayout.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/gui/editors/matrix/MatrixHLayout.h b/src/gui/editors/matrix/MatrixHLayout.h
index 291d618..76f1b31 100644
--- a/src/gui/editors/matrix/MatrixHLayout.h
+++ b/src/gui/editors/matrix/MatrixHLayout.h
@@ -62,7 +62,7 @@ public:
timeT = 0);
/**
* Returns the total length of all elements once tqlayout is done.
* This is the x-coord of the end of the last element on the
* longest staff
*/
@@ -84,9 +84,9 @@ public:
virtual double getBarPosition(int barNo) const;
/**
* Precomputes tqlayout data for a single staff, updating any
* internal data stores associated with that staff and updating
* any tqlayout-related properties in the events on the staff's
* segment.
*/
virtual void scanStaff(Staff&,
@@ -94,10 +94,10 @@ public:
timeT = 0);
/**
* Computes any tqlayout data that may depend on the results of
* scanning more than one staff. This may mean doing most of
* the tqlayout (likely for horizontal tqlayout) or nothing at all
* (likely for vertical tqlayout).
*/
virtual void finishLayout(timeT = 0,
timeT = 0);
@@ -118,7 +118,7 @@ protected:
// pair of has-time-sig and time-sig
typedef std::pair<bool, TimeSignature> TimeSigData;
// pair of tqlayout-x and time-signature if there is one
typedef std::pair<double, TimeSigData> BarData;
typedef FastVector<BarData> BarDataList;
BarDataList m_barData;
@@ -133,7 +133,7 @@ protected:
*/
class ZoomableMatrixHLayoutRulerScale : public RulerScale, public HZoomable {
public:
- ZoomableMatrixHLayoutRulerScale(MatrixHLayout& tqlayout) : RulerScale(tqlayout.getComposition()), m_referenceHLayout(tqlayout) {};
+ ZoomableMatrixHLayoutRulerScale(MatrixHLayout& layout) : RulerScale(layout.getComposition()), m_referenceHLayout(layout) {};
virtual double getBarPosition(int n) const { return m_referenceHLayout.getBarPosition(n) * getHScaleFactor(); }
virtual double getXForTime(timeT time) const { return m_referenceHLayout.getXForTime(time) * getHScaleFactor(); }
@@ -62,7 +62,7 @@ public:
timeT = 0);
/**
- * Returns the total length of all elements once tqlayout is done.
+ * Returns the total length of all elements once layout is done.
* This is the x-coord of the end of the last element on the
* longest staff
@@ -84,9 +84,9 @@ public:
virtual double getBarPosition(int barNo) const;
/**
- * Precomputes tqlayout data for a single staff, updating any
+ * Precomputes layout data for a single staff, updating any
* internal data stores associated with that staff and updating
@@ -84,9 +84,9 @@ public:
* internal data stores associated with that staff and updating
- * any tqlayout-related properties in the events on the staff's
+ * any layout-related properties in the events on the staff's
* segment.
*/
@@ -94,10 +94,10 @@ public:
timeT = 0);
/**
- * Computes any tqlayout data that may depend on the results of
+ * Computes any layout data that may depend on the results of
* scanning more than one staff. This may mean doing most of
@@ -94,10 +94,10 @@ public:
* scanning more than one staff. This may mean doing most of
- * the tqlayout (likely for horizontal tqlayout) or nothing at all
- * (likely for vertical tqlayout).
+ * the layout (likely for horizontal layout) or nothing at all
+ * (likely for vertical layout).
*/
virtual void finishLayout(timeT = 0,
@@ -118,7 +118,7 @@ protected:
// pair of has-time-sig and time-sig
typedef std::pair<bool, TimeSignature> TimeSigData;
- // pair of tqlayout-x and time-signature if there is one
+ // pair of layout-x and time-signature if there is one
typedef std::pair<double, TimeSigData> BarData;
typedef FastVector<BarData> BarDataList;